pub struct ModelsError {
pub code: ModelsErrorCode,
/* private fields */
}Expand description
Shared models/auth failure with a stable code.
Fields
code: ModelsErrorCodeStable error classification.
Implementations
Sourceimpl ModelsError
impl ModelsError
Sourcepub fn new(code: ModelsErrorCode, message: impl Into<String>) -> Self
pub fn new(code: ModelsErrorCode, message: impl Into<String>) -> Self
Create a models error from a code and message.
Sourcepub fn cancelled() -> Self
pub fn cancelled() -> Self
Create a request-cancellation error without expanding the stable
ModelsErrorCode wire contract.
Sourcepub const fn is_cancelled(&self) -> bool
pub const fn is_cancelled(&self) -> bool
Whether auth resolution stopped because its request was cancelled.